#ifndef DBMX1_AITC_H
#define DBMX1_AITC_H 

/*******************************************************************************
*
* Copyright (C) 2001, MOTOROLA INC.   All Rights Reserved
*
*  FILE NAME      :  DBMX1_AITC.h
*  DATE CREATED   :  5/10/01
*
*  DESCRIPTION:
*  This is a header file for the DBMX1 AITC test code.  It contains the 
*  function prototypes for the normal and fast interrupt service routines.
*  It should be included in those files that contain calls to these functions. 
*
*******************************************************************************/

/**************** Define AITC register addresses ***********************/

/* set the base address of the AITC module */
#define AITC_BASE_ADDRESS 0x00223000	

/* According to the spec, AITC registers cannot be accessed by byte or halfword 
** accesses, they can only be accessed by word accesses. Therefore, we will not
** include bit definitions for the AITC module, only register address 
** definitions 
*/ 

#define INTCNTL		(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x00))
#define NIMASK		(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x04))
#define INTENNUM	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x08))
#define INTDISNUM	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x0C))
#define INTENABLEH	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x10))
#define INTENABLEL	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x14))
#define INTTYPEH	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x18))
#define INTTYPEL	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x1C))
#define NIPRIORITY7	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x20))
#define NIPRIORITY6	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x24))
#define NIPRIORITY5	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x28))
#define NIPRIORITY4	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x2C))
#define NIPRIORITY3	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x30))
#define NIPRIORITY2	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x34))
#define NIPRIORITY1	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x38))
#define NIPRIORITY0	(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x3C))
#define NIVECSR		(*(volatile int			 *) (AITC_BASE_ADDRESS + 0x40))
#define FIVECSR		(*(volatile int			 *) (AITC_BASE_ADDRESS + 0x44))
#define INTSRCH		(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x48))
#define INTSRCL		(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x4C))
#define INTFRCH		(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x50))
#define INTFRCL		(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x54))
#define NIPNDH		(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x58))
#define NIPNDL		(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x5C))
#define FIPNDH		(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x60))
#define FIPNDL		(*(volatile unsigned int *) (AITC_BASE_ADDRESS + 0x64))

#define CSCR		(*(volatile unsigned int *) (0x0021B000))

/* Interrupt Service Routines function prototypes */
void   fast_dummy_isr(void);	// fast_dummy_isr 
void   norm_dummy_isr(void);	// norm_dummy_isr 
void   norm_src54_isr(void);	// ISR (54)
void   fast_src05_isr(void);	// ISR (05)


#endif  // inclusion guard