/*******************************************************************************
*
*  Copyright (C) 2001, MOTOROLA INC.   All Rights Reserved
*
*  FILE NAME            :  DBMX1_AITC_TEMPLATE_MAIN.c
*  PROJECT              :  DBMX1/MXL 
*  DATE CREATED         :  
*  CREATOR              :  MOTOROLA 
*	
*
*	DESCRIPTION: This is a template for using the AITC on the DBMX1.
*	List of steps needed in normal situations to enable interrupts:
*	1. Enable the interrupt in the peripheral (i.e. UART, USBd, SPI, etc.)
*	   - in the case of this template, the INTFRCH/L registers will be used
*		 to generate interrupts	
*	2. Enable the interrupt in the AITC
*	3. Enable the interrupt to the ARM920T core via the CPSR register (I and F bits)
*
*
*	REVISION HISTORY:
*	Release 0.1 - initial release
*	Release 0.2 - updated comments
*  
*******************************************************************************/


/***************************************
*  Include Files
****************************************/
#include "DBMX1_AITC.h"					// header file for AITC specific register defn and function prototypes
#include <stdio.h>						// standard I/O library, for printf statements

/***************************************
*  Function Prototypes
****************************************/


/***************************************
*  Defines
****************************************/

/***************************************
* Globals  
****************************************/

/* ISR flags */
extern volatile int gIntSrc54;
extern volatile int gIntSrc5;

	
/**********************************************************************************
* Inline functions to enable and disable interrupts 
* Interrupts are enabled or disabled by reading the cpsr flags and updating bit 7.
* The same can be done with fast interrupts by updating bit 6. 
* These functions work only in a privileged mode, because the control bits of the 
* cpsr and spsr cannot be changed while in User mode.
**********************************************************************************/
//enable and disable interrupts to the ARM core function definitions

__inline void enable_IRQ(void)
{
    int tmp;
    __asm
    {
        MRS tmp, CPSR
        BIC tmp, tmp, #0x80
        MSR CPSR_c, tmp
    }
}

__inline void disable_IRQ(void)
{
    int tmp;
    __asm
    {
        MRS tmp, CPSR
        ORR tmp, tmp, #0x80
        MSR CPSR_c, tmp
    }
}

__inline void enable_FIQ(void)
{
    int tmp;
    __asm
    {
        MRS tmp, CPSR
        BIC tmp, tmp, #0x40
        MSR CPSR_c, tmp
    }
}

__inline void disable_FIQ(void)
{
    int tmp;
    __asm
    {
        MRS tmp, CPSR
        ORR tmp, tmp, #0x40
        MSR CPSR_c, tmp
    }
}


/*************************************
*  Main
**************************************/

void main() 
{

	// initialize global variables
	gIntSrc54 = 0;
	gIntSrc5 = 0;

	// Set up Clock divider in the CSCR
	CSCR &= 0xFFFFC3FF;


	//*************
	// AITC set up
	//*************
	// Set up interrupt types (0=Normal, 1=Fast), these registers defauly to 0x0000000, or all Normal types 
	INTTYPEH |= 0xAAAAAAAA;			//Assign odd bits as fast interrupts, even as normal
	INTTYPEL |= 0xAAAAAAAA;

	// Enable the interrupt sources in the AITC 
	INTENABLEH |= 0x00400000;	//enable int src 54
	INTENABLEL |= 0x00000020;	//enable int src 5


	// Enable the interrupts in the ARM920T core via the CPSR (clear I and F bits)
	enable_IRQ();
	enable_FIQ();

	//******************************************************************************
	// Your code goes here to generate interrupts.  In this case we will make use of 
	// Interrupt Force Registers to software force interrupts to occur.
	//******************************************************************************
	INTFRCH |= 0x00400000; 	// force interrupt source bit 54
	
	printf("Executing interrupt source 54\n");  // need a slight delay here to allow interrupt to be serviced
												// a latency in S/W	
	
	if (gIntSrc54 != 1)
	{
		printf("Failure, we should have executed ISR for source 54.\n");
	}
	
	INTFRCL |= 0x00000020; 	// force interrupt source bit 5

	printf("Executing interrupt source 5\n");  //need a slight delay here to allow interrupt to be serviced

	if(gIntSrc5 != 1)
	{
		printf("Failure, we should have executed ISR for source 5.\n");
	}
	
	if ((gIntSrc54 == 1)&&(gIntSrc5 == 1))
	{
		printf("Interrupt tests passed.\n");
	}
}
