/*******************************************************************************
*
* Copyright (C) 2001, MOTOROLA INC.   All Rights Reserved
*
*  	FILE NAME      :  int_handler.c
*  	DATE CREATED   :  5/10/01
*
*  	DESCRIPTION:
*  	This is the interrupt handler for DBMX1 
*
*	When an interrupt occurs, the core fetches the address of the ISR from
*	the vector table (vectors.s).  Depending on interrupt type (normal or fast),
*  	either IRQ_Handler(void) or FIQ_Handler(void) will be called. In these 
*	routines, the NIVECSR or FIVECSR will be read to determine the source 
*	number of the interrupt. Then, this number will be passed to a function
*	that invokes a "look-up" table to determine which ISR will be exectued.
*	
*	Upon completion of the specific ISR, the code will return to the
*	int_handler routine, and thus return to the main program. This is made
*	possible by preceding the name of the interrupt handlers with the
*   keyword "__irq". 
*
*******************************************************************************/
#include "DBMX1_AITC.h"

#include <stdio.h>

typedef void (*FUNCT)(void);		// define a pointer to a function

// when you write a new Interrupt Service Routine (ISR), be sure to 
// include it's name in the proper place of these arrays.

// look up table of normal ISRs 
FUNCT vect_IRQ[64] = {norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,  
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,  
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,  
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,  
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,  
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,  
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr,  
					 norm_dummy_isr, norm_dummy_isr, norm_src54_isr, norm_dummy_isr,
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, 
					 norm_dummy_isr, norm_dummy_isr, norm_dummy_isr, norm_dummy_isr};

// look up table of fast ISRs
FUNCT vect_FIQ[64] = {fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,  
					 fast_dummy_isr, fast_src05_isr, fast_dummy_isr, fast_dummy_isr,
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,  
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,  
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,  
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,  
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,  
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,  
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr,
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, 
					 fast_dummy_isr, fast_dummy_isr, fast_dummy_isr, fast_dummy_isr};
					
/***************************************
* Globals  
****************************************/

#define NUM_INT_SOURCES	64

// ISR flags 
volatile int gIntSrc54;
volatile int gIntSrc5;

/******************************************************************************
* IRQ_Handler                                                                 *
* This function handles IRQ interrupts.  				                      *
******************************************************************************/

void __irq IRQ_Handler(void)
{
	short vectNum;

	vectNum = NIVECSR >> 16;	// determine highest pending normal interrupt		
	vect_IRQ[vectNum]();		// find the pointer to correct ISR in the look up table

}


/******************************************************************************
* FIQ_Handler                                                                 *
* This function handles IRQ interrupts.  				                      *
******************************************************************************/

void __irq FIQ_Handler(void)
{
	short vectNum;

	vectNum = FIVECSR & 0x0000003F;	// determine highest pending fast interrupt
	vect_FIQ[vectNum]();		// find the pointer to correct ISR in the look up table

}



/*******************************************************************************
*
*  Interrupt Handlers (64 fast int sources and 64 normal int sources)
*	
*	ADD your custom ISRs here...be sure to add the names in the above arrays.
*
*******************************************************************************/


/***********************/
/* Fast Interrupt ISRs */
/***********************/


void   fast_dummy_isr(void)		// fast_dummy_isr 
{
	printf("ERROR, you've entered a FAST Interrupt dummy ISR!\n");
}

void   fast_src05_isr(void)
{
	//clear the sorc of the interrupt
	INTFRCL &= 0xFFFFFFDF;
	
	//set the global flag
	gIntSrc5 = 1;
}

/*************************/
/* Normal Interrupt ISRs */
/*************************/

void   norm_dummy_isr(void)	// norm_dummy_isr 
{
	printf("ERROR, you've entered a NORMAL Interrupt dummy ISR!\n");
}


void   norm_src54_isr(void)
{
	//clear the sorc of the interrupt
	INTFRCH &= 0xFFBFFFFF;
	
	//set the global flag
	gIntSrc54 = 1;
}

